@@ -18,11 +18,11 @@ function (x, y, weights = rep(1, nobs), start = NULL, etastart = NULL,
   eval(family$initialize)
   if (coefprior$family == "BIC") coefprior$hyper = as.numeric(nobs)
 
-  newfit = .Call("glm_fit",
+  newfit = .Call(C_glm_fit,
     RX=x, RY = y,
     family=family, Roffset = offset,
     Rweights = weights,
-      Rpriorcoef = coefprior, Rcontrol=control, PACKAGE="BAS")
+      Rpriorcoef = coefprior, Rcontrol=control)
 
   return(newfit)
 }
